@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PPPort;
 {
-  $Dist::Zilla::Plugin::PPPort::VERSION = '0.002';
+  $Dist::Zilla::Plugin::PPPort::VERSION = '0.003';
 }
 
 use 5.008;
@@ -9,14 +9,22 @@ with qw/Dist::Zilla::Role::FileGatherer/;
 use Devel::PPPort;
 
 my $content;
-open PPPORT_FILE, '>', \$content or confess "Couldn't open scalar filehandle";
-Devel::PPPort::WriteFile("&=".__PACKAGE__."::PPPORT_FILE");
-close PPPORT_FILE;
+{
+	local *PPPORT_FILE;
+	open PPPORT_FILE, '>', \$content or confess "Couldn't open scalar filehandle";
+	Devel::PPPort::WriteFile("&=".__PACKAGE__."::PPPORT_FILE");
+	close PPPORT_FILE;
+}
+
+has filename => (
+	is => 'ro',
+	isa => 'Str',
+	default => 'ppport.h'
+);
 
 sub gather_files {
 	my $self = shift;
-	my $file = Dist::Zilla::File::InMemory->new(name => 'ppport.h', content => $content);
-	$self->add_file($file);
+	$self->add_file(Dist::Zilla::File::InMemory->new(name => $self->filename, content => $content));
 	return;
 }
 
@@ -32,13 +40,18 @@ Dist::Zilla::Plugin::PPPort - PPPort for Dist::Zilla
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
 In your dist.ini
 
  [PPPort]
+ filename = ppport.h ;default
+
+=head1 DESCRIPTION
+
+This module adds a PPPort file to your distribution. By default it's called C<ppport.h>, but you can name differently.
 
 =for Pod::Coverage gather_files
 =end
